=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2011-06-24 15:25:06 +0000
+++ drizzled/drizzled.cc	2011-07-12 23:34:13 +0000
@@ -1422,7 +1422,7 @@
   if (sys_var_init())
     return 1;
   /* Creates static regex matching for temporal values */
-  if (! init_temporal_formats())
+  if (not init_temporal_formats())
     return 1;
 
   if (!(default_charset_info=

=== modified file 'drizzled/temporal_format.cc'
--- drizzled/temporal_format.cc	2011-06-23 11:06:21 +0000
+++ drizzled/temporal_format.cc	2011-07-12 23:34:13 +0000
@@ -66,6 +66,11 @@
                     );
 }
 
+TemporalFormat::~TemporalFormat()
+{
+  pcre_free(_re);
+}
+
 bool TemporalFormat::matches(const char *data, size_t data_len, Temporal *to)
 {
   if (! is_valid()) 

=== modified file 'drizzled/temporal_format.h'
--- drizzled/temporal_format.h	2011-03-29 12:45:08 +0000
+++ drizzled/temporal_format.h	2011-07-12 23:34:13 +0000
@@ -63,6 +63,9 @@
    * @param Pattern to use in matching
    */
   TemporalFormat(const char *pattern);
+
+  ~TemporalFormat();
+
   /**
    * Returns whether the instance is compiled
    * and contains a valid regular expression.

=== modified file 'm4/pandora_have_libcurl.m4'
--- m4/pandora_have_libcurl.m4	2011-03-07 16:42:18 +0000
+++ m4/pandora_have_libcurl.m4	2011-07-12 23:34:13 +0000
@@ -32,10 +32,14 @@
      AC_COMPILE_IFELSE([
        AC_LANG_PROGRAM(
          [[
-           CURL *handle;
-           handle=curl_easy_init();
-           rv= curl_easy_setopt(curl_handle, CURLOPT_USERNAME, "foo");
-         ]])],
+           #include <curl/curl.h>
+         ]],
+         [[
+           CURL *curl_handle=curl_easy_init();
+           CURLcode rv= curl_easy_setopt(curl_handle, CURLOPT_USERNAME, "foo");
+           (void)rv;
+         ]])
+       ],
        [pandora_cv_curl_have_username=yes],
        [pandora_cv_curl_have_username=no])
      ])

=== modified file 'plugin/json_server/json_server.cc'
--- plugin/json_server/json_server.cc	2011-04-21 07:15:35 +0000
+++ plugin/json_server/json_server.cc	2011-07-12 23:34:13 +0000
@@ -20,10 +20,15 @@
 
 
 #include <config.h>
+
+#include <unistd.h>
+#include <fcntl.h>
+
 #include <drizzled/module/module.h>
 #include <drizzled/module/context.h>
 #include <drizzled/plugin/plugin.h>
 #include <drizzled/plugin.h>
+#include <drizzled/plugin/daemon.h>
 #include <drizzled/sys_var.h>
 #include <drizzled/gettext.h>
 #include <drizzled/error.h>
@@ -38,7 +43,6 @@
 #include <drizzled/constrained_value.h>
 #include <evhttp.h>
 #include <event.h>
-#include <pthread.h>
 #include <drizzled/execute.h>
 #include <drizzled/sql/result_set.h>
 
@@ -46,6 +50,10 @@
 #include <drizzled/plugin/client.h>
 #include <drizzled/catalog/local.h>
 
+#include <drizzled/pthread_globals.h>
+#include <boost/bind.hpp>
+
+
 #include <drizzled/version.h>
 #include <plugin/json_server/json/json.h>
 
@@ -59,8 +67,6 @@
 {
 
 static port_constraint port;
-struct event_base *base= NULL;
-struct evhttp *httpd;
 
 static in_port_t getPort(void)
 {
@@ -222,48 +228,139 @@
   evhttp_send_reply(req, HTTP_OK, "OK", buf);
 }
 
-extern "C" void *libevent_thread(void*);
-
-extern "C" void *libevent_thread(void*)
+static void shutdown_event(int fd, short, void *arg)
+{
+  struct event_base *base= (struct event_base *)arg;
+  event_base_loopbreak(base);
+  close(fd);
+}
+
+
+static void run(struct event_base *base)
 {
   internal::my_thread_init();
 
   event_base_dispatch(base);
-  evhttp_free(httpd);
-  return NULL;
 }
 
+
+class JsonServer : public drizzled::plugin::Daemon
+{
+private:
+  JsonServer(const JsonServer &);
+  JsonServer& operator=(const JsonServer &);
+
+  drizzled::thread_ptr json_thread;
+  in_port_t _port;
+  struct evhttp *httpd;
+  struct event_base *base;
+  int wakeup_fd[2];
+  struct event wakeup_event;
+
+public:
+  JsonServer(in_port_t port_arg) :
+    drizzled::plugin::Daemon("JSON Server"),
+    _port(port_arg),
+    httpd(NULL),
+    base(NULL)
+  { }
+
+  bool init()
+  {
+    if (pipe(wakeup_fd) < 0)
+    {
+      sql_perror("pipe");
+      return false;
+    }
+
+    int returned_flags;
+    if ((returned_flags= fcntl(wakeup_fd[0], F_GETFL, 0)) < 0)
+    {
+      sql_perror("fcntl:F_GETFL");
+      return false;
+    }
+
+    if (fcntl(wakeup_fd[0], F_SETFL, returned_flags | O_NONBLOCK) < 0)
+
+    {
+      sql_perror("F_SETFL");
+      return false;
+    }
+
+    if ((base= event_init()) == NULL)
+    {
+      sql_perror("event_init()");
+      return false;
+    }
+
+    if ((httpd= evhttp_new(base)) == NULL)
+    {
+      sql_perror("evhttp_new()");
+      return false;
+    }
+
+
+    if ((evhttp_bind_socket(httpd, "0.0.0.0", getPort())) == -1)
+    {
+      sql_perror("evhttp_bind_socket()");
+      return false;
+    }
+
+    evhttp_set_cb(httpd, "/", process_root_request, NULL);
+    evhttp_set_cb(httpd, "/0.1/version", process_api01_version_req, NULL);
+    evhttp_set_cb(httpd, "/0.1/sql", process_api01_sql_req, NULL);
+    evhttp_set_gencb(httpd, process_request, NULL);
+
+    event_set(&wakeup_event, wakeup_fd[0], EV_READ | EV_PERSIST, shutdown_event, base);
+    event_base_set(base, &wakeup_event);
+    if (event_add(&wakeup_event, NULL) < 0)
+    {
+      sql_perror("event_add");
+      return false;
+    }
+
+    json_thread.reset(new boost::thread((boost::bind(&run, base))));
+
+    if (not json_thread)
+      return false;
+
+    return true;
+  }
+
+  ~JsonServer()
+  {
+    // If we can't write(), we will just muddle our way through the shutdown
+    char buffer[1];
+    buffer[0]= 4;
+    if ((write(wakeup_fd[1], &buffer, 1)) == 1)
+    {
+      json_thread->join();
+      evhttp_free(httpd);
+      event_base_free(base);
+    }
+  }
+};
+
 static int json_server_init(drizzled::module::Context &context)
 {
   context.registerVariable(new sys_var_constrained_value_readonly<in_port_t>("port", port));
 
-  base= event_init();
-  httpd= evhttp_new(base);
-  if (httpd == NULL)
-    return -1;
-
-  int r= evhttp_bind_socket(httpd, "0.0.0.0", getPort());
-
-  if (r != 0)
+  JsonServer *server;
+  context.add(server= new JsonServer(port));
+
+  if (server and not server->init())
+  {
     return -2;
-
-  evhttp_set_cb(httpd, "/", process_root_request, NULL);
-  evhttp_set_cb(httpd, "/0.1/version", process_api01_version_req, NULL);
-  evhttp_set_cb(httpd, "/0.1/sql", process_api01_sql_req, NULL);
-  evhttp_set_gencb(httpd, process_request, NULL);
-
-  pthread_t libevent_loop_thread;
-
-  pthread_create(&libevent_loop_thread, NULL, libevent_thread, NULL);
-
-  return 0;
+  }
+
+  return bool(server) ? 0 : 1;
 }
 
 static void init_options(drizzled::module::option_context &context)
 {
   context("port",
-          po::value<port_constraint>(&port)->default_value(80),
-          _("Port number to use for connection or 0 for default (port 80) "));
+          po::value<port_constraint>(&port)->default_value(8086),
+          _("Port number to use for connection or 0 for default (port 8086) "));
 }
 
 } /* namespace json_server */

=== modified file 'plugin/json_server/plugin.ini'
--- plugin/json_server/plugin.ini	2011-05-02 07:45:56 +0000
+++ plugin/json_server/plugin.ini	2011-07-12 23:34:13 +0000
@@ -4,9 +4,23 @@
 version=0.1
 author=Stewart Smith
 license=PLUGIN_LICENSE_GPL
-headers= json/autolink.h json/config.h json/features.h json/forwards.h json/json_batchallocator.h json/json.h json/reader.h json/value.h json/writer.h json/json_internalarray.inl json/json_internalmap.inl json/json_valueiterator.inl
+headers= 
+  json/autolink.h
+  json/config.h
+  json/features.h
+  json/forwards.h
+  json/json_batchallocator.h
+  json/json.h
+  json/reader.h
+  json/value.h
+  json/writer.h
+  json/json_internalarray.inl
+  json/json_internalmap.inl
+  json/json_valueiterator.inl
 sources=
-  json_server.cc json/json_reader.cpp json/json_value.cpp json/json_writer.cpp
+  json_server.cc
+  json/json_reader.cpp
+  json/json_value.cpp
+  json/json_writer.cpp
 build_conditional="x${ac_cv_libevent}" = "xyes" -a "x${ac_cv_libcurl}" = "xyes"
 ldflags=${LTLIBEVENT}
-

